@@ -23,7 +23,7 @@ use base qw[ Class::Accessor::Fast ];
 __PACKAGE__->mk_accessors( qw[ _host _password _port  _version ] );
 
 
-our $VERSION = '0.5.3';
+our $VERSION = '0.6.0';
 
 
 #
@@ -102,9 +102,9 @@ sub spawn {
             },
             $collection => { # collection related commands
                 # -- Collection: retrieving songs & directories
-# #                 all_items
-# #                 all_items_simple
-# #                 items_in_dir
+                'coll.all_items'        => '_onpub_all_items',
+                'coll.all_items_simple' => '_onpub_all_items_simple',
+                'coll.items_in_dir'     => '_onpub_items_in_dir',
                 # -- Collection: retrieving the whole collection
 # #                 all_songs
 # #                 all_albums
